' -----------------------------------------------------------
' Class for driving ledWIZ via DLL

' needs a 128 x 16 DMD on the translite / table called LEDdmd
' -----------------------------------------------------------

Class tl

	Private PortState(32)
	Private PortLevel(32)
	Private GPS

	Private Lp
	Private s

	private sub Class_Initialize()
		' Add the font for the binary coded data
		LedDMD.AddFont 1, "binary-font"


		' All Off to start, level set to 48
		For Lp = 0 to 31
			PortState(Lp) = 0
			PortLevel(Lp) = 48
		Next 
		GPS = 1
		Show()
	End Sub

	' ----------------------------------
	' Seton is used to turn a channel on
	'
	' Channel can be from 1 to 32
	' ----------------------------------

	Sub SetOn(ByVal Channel)
		if Channel < 33 then
			PortState(Channel-1) = 1
		end if
		Show
	End Sub

	' ------------------------------------
	' Setoff is used to turn a channel off
	'
	' Channel can be from 1 to 32
	' ------------------------------------

	Sub SetOff(ByVal Channel)
		if Channel < 33 then
			PortState(Channel-1) = 0
		end if
		Show
	End Sub

	' ----------------------------------
	' SetGlobalPulseSpeed is used to set
	' the Global Pulse Speed parameter
	'
	' Pulse speed should be from 1 to 7
	' ----------------------------------

	sub SetGlobalPulseSpeed(ByVal Level)
		GPS = Level and 7							' limit to 7 max
		Show
	End Sub

	' ----------------------------------
	' Power is used to set the level for 
	' any of the channels
	'
	' Channel can be from 1 to 32
	' Level can be from 0 to 255
	' ----------------------------------

	sub Power(ByVal Channel, ByVal Level)
		' Update array with new level
		if Channel < 33 then
			PortLevel(Channel-1) = Level
		end if
		Show
	End Sub

	' -----------------------------------
	' This routine codes all of the above
	' into a pattern of pixels that can
	' be unravelled by the DLL to then
	' pass the information on to LEDwiz
	' -----------------------------------

	sub Show
		' Set the identifier in the relevant place on the DMD 
		s = "[pix0,0,0][pix2,1,0][pix2,2,0][pix4,3,0]"

		' code the 32 port states on line 1
		For Lp = 0 to 31
			s = s + "[pix"&PortState(Lp)&","&Lp&",1]"
		Next

		' Code the global pulse speed after the port states
		s = s & "[f1][x32][y1]" & chr(48 + GPS)

		' code the port levels as nibbles on line 2
		s = s & "[x0][y2]"
		For Lp = 0 to 31
			s = s & Chr(48 + ((PortLevel(Lp) \ 16) and 15)) & chr(48 + (PortLevel(Lp) and 15))
		Next

		' Display it so DLL can pick it up
		LEDdmd.Text = s 
	End Sub

End Class
